from PyQt5.QtWidgets import QApplication,  QMainWindow
import sys
from PyQt5 import QtGui



class Window(QMainWindow):
    def __init__(self):
        super().__init__()

        self.setGeometry(300, 300, 500, 400)
        self.setWindowTitle("Figure PyQt5 EMachinerY")

        # self.textbox = QLinez

        self.show()

def run():
    App = QApplication(sys.argv)
    window = Window()
    sys.exit(App.exec())

if __name__ == '!__main__':
    run()







import sys
import time

import numpy as np

# https://matplotlib.org/3.3.2/gallery/user_interfaces/embedding_in_qt_sgskip.html
from matplotlib.backends.qt_compat import QtCore, QtWidgets
from matplotlib.backends.backend_qt5agg import (
    FigureCanvas, NavigationToolbar2QT as NavigationToolbar)
from matplotlib.figure import Figure


class ApplicationWindow(QtWidgets.QMainWindow):
    def __init__(self):
        super().__init__()

        self.initUI_matplotlib()
        self.initUI()

    def initUI_matplotlib(self):
        self._main = QtWidgets.QWidget()
        self.setCentralWidget(self._main)
        layout = QtWidgets.QVBoxLayout(self._main)

        static_canvas = FigureCanvas(Figure(figsize=(5, 3)))
        layout.addWidget(static_canvas)
        self.addToolBar(NavigationToolbar(static_canvas, self))

        dynamic_canvas = FigureCanvas(Figure(figsize=(5, 3)))
        layout.addWidget(dynamic_canvas)
        self.addToolBar(QtCore.Qt.BottomToolBarArea,
                        NavigationToolbar(dynamic_canvas, self))

        self._static_ax = static_canvas.figure.subplots()
        t = np.linspace(0, 10, 501)
        self._static_ax.plot(t, np.tan(t), ".")

        self._dynamic_ax = dynamic_canvas.figure.subplots()
        t = np.linspace(0, 10, 101)
        # Set up a Line2D.
        self._line, = self._dynamic_ax.plot(t, np.sin(t + time.time()))
        self._timer = dynamic_canvas.new_timer(50)
        self._timer.add_callback(self._update_canvas)
        self._timer.start()

    def initUI(self):

        layout = QtWidgets.QVBoxLayout(self._main)

        # my code
        self.setWindowTitle('Figure emachinery')
        self.label1 = QtWidgets.QLabel(self)
        self.label1.setText('TT')
        self.label1.move(200,200)

        b1 = QtWidgets.QPushButton(self)
        b1.setText('Scie me')
        def b1_clicked():
            self.label1.setText('you clicked')
            # self._update_label()
        b1.clicked.connect(b1_clicked)
        layout.addWidget(b1)

    # def _update_label(self):
    #     self.label1.adjustSize()

    def _update_canvas(self):
        t = np.linspace(0, 10, 101)
        # Shift the sinusoid as a function of time.
        self._line.set_data(t, np.sin(t + time.time()))
        self._line.figure.canvas.draw()


if __name__ == "!__main__":
    # Check whether there is already a running QApplication (e.g., if running
    # from an IDE).
    qapp = QtWidgets.QApplication.instance()
    if not qapp:
        qapp = QtWidgets.QApplication(sys.argv)

    app = ApplicationWindow()
    app.show()
    app.activateWindow()
    app.raise_()
    qapp.exec_()














from threading import Thread
from pyqtconsole.console import PythonConsole
if __name__ == '!__main__':

    app = QApplication([])
    console = PythonConsole()
    console.show()
    console.eval_in_thread()

    sys.exit(app.exec_())






# https://stackoverflow.com/questions/11513132/embedding-ipython-qt-console-in-a-pyqt-application
from qtconsole.qt import QtGui
from qtconsole.rich_jupyter_widget import RichJupyterWidget
from qtconsole.inprocess import QtInProcessKernelManager

import logging

class ConsoleWidget(RichJupyterWidget):

    def __init__(self, customBanner=None, *args, **kwargs):
        super(ConsoleWidget, self).__init__(*args, **kwargs)

        if customBanner is not None:
            self.banner = customBanner

        self.font_size = 6
        self.kernel_manager = kernel_manager = QtInProcessKernelManager()

        kernel_manager.start_kernel(show_banner=False)
        # kernel_manager.kernel.log.setLevel(logging.CRITICAL) # 
        kernel_manager.kernel.gui = 'qt'
        self.kernel_client = kernel_client = self._kernel_manager.client()
        kernel_client.start_channels()

        def stop():
            kernel_client.stop_channels()
            kernel_manager.shutdown_kernel()
            guisupport.get_app_qt().exit()

        self.exit_requested.connect(stop)

    def push_vars(self, variableDict):
        """
        Given a dictionary containing name / value pairs, push those variables
        to the Jupyter console widget
        """
        self.kernel_manager.kernel.shell.push(variableDict)

    def clear(self):
        """
        Clears the terminal
        """
        self._control.clear()

        # self.kernel_manager

    def print_text(self, text):
        """
        Prints some plain text to the console
        """
        self._append_plain_text(text)

    def execute_command(self, command):
        """
        Execute a command in the frame of the console widget
        """
        self._execute(command, False)


if __name__ == '__main__':
    app = QtGui.QApplication([])
    widget = ConsoleWidget()
    widget.show()
    app.exec_()



# coding:u8
# this allows to use "from utils import conversion" in __main__.py
import os, sys
sys.path.append(os.path.dirname(os.path.realpath(__file__))) # https://stackoverflow.com/questions/16981921/relative-imports-in-python-3
sys.path.append(os.path.dirname(os.path.realpath(__file__+'/gui'))) # 为了不需要手动修改 mainWindow.py 中的相对路径的 import 
sys.path.append(os.path.dirname(os.path.realpath(__file__+'/utils')))
sys.path.append(os.path.dirname(os.path.realpath(__file__+'/jsons')))
sys.path.append(os.path.dirname(os.path.realpath(__file__+'/acmdesignv2')))
# sys.path.append(os.path.dirname(os.path.realpath(__file__+'/newcode')))

__version__ = '1.0.9'
__description__ = 'A GUI for analysis of electric machinery'
__author__ = 'Jiahao Chen'
__author_email__ = 'horychen@qq.com'
__url__ = 'https://github.com/horychen/emachinery'



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainWindow.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(800, 945)
        MainWindow.setStyleSheet("")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setGeometry(QtCore.QRect(0, 0, 801, 921))
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.verticalLayoutWidget = QtWidgets.QWidget(self.tab)
        self.verticalLayoutWidget.setGeometry(QtCore.QRect(10, 10, 288, 199))
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.verticalLayoutWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.comboBox_MachineType = QtWidgets.QComboBox(self.verticalLayoutWidget)
        self.comboBox_MachineType.setObjectName("comboBox_MachineType")
        self.comboBox_MachineType.addItem("")
        self.comboBox_MachineType.addItem("")
        self.verticalLayout.addWidget(self.comboBox_MachineType)
        self.comboBox_MachineName = QtWidgets.QComboBox(self.verticalLayoutWidget)
        self.comboBox_MachineName.setObjectName("comboBox_MachineName")
        self.verticalLayout.addWidget(self.comboBox_MachineName)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label_npd = QtWidgets.QLabel(self.verticalLayoutWidget)
        self.label_npd.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_npd.setObjectName("label_npd")
        self.verticalLayout_2.addWidget(self.label_npd)
        self.label_npd_2 = QtWidgets.QLabel(self.verticalLayoutWidget)
        self.label_npd_2.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_2.setObjectName("label_npd_2")
        self.verticalLayout_2.addWidget(self.label_npd_2)
        self.label_npd_3 = QtWidgets.QLabel(self.verticalLayoutWidget)
        self.label_npd_3.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_3.setObjectName("label_npd_3")
        self.verticalLayout_2.addWidget(self.label_npd_3)
        self.label_npd_4 = QtWidgets.QLabel(self.verticalLayoutWidget)
        self.label_npd_4.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_4.setObjectName("label_npd_4")
        self.verticalLayout_2.addWidget(self.label_npd_4)
        self.horizontalLayout.addLayout(self.verticalLayout_2)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.lineEdit_npp = QtWidgets.QLineEdit(self.verticalLayoutWidget)
        self.lineEdit_npp.setObjectName("lineEdit_npp")
        self.verticalLayout_3.addWidget(self.lineEdit_npp)
        self.lineEdit_RatedCurrent = QtWidgets.QLineEdit(self.verticalLayoutWidget)
        self.lineEdit_RatedCurrent.setObjectName("lineEdit_RatedCurrent")
        self.verticalLayout_3.addWidget(self.lineEdit_RatedCurrent)
        self.lineEdit_RatedPower = QtWidgets.QLineEdit(self.verticalLayoutWidget)
        self.lineEdit_RatedPower.setObjectName("lineEdit_RatedPower")
        self.verticalLayout_3.addWidget(self.lineEdit_RatedPower)
        self.lineEdit_RatedSpeed = QtWidgets.QLineEdit(self.verticalLayoutWidget)
        self.lineEdit_RatedSpeed.setObjectName("lineEdit_RatedSpeed")
        self.verticalLayout_3.addWidget(self.lineEdit_RatedSpeed)
        self.horizontalLayout.addLayout(self.verticalLayout_3)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem)
        self.pushButton_updateModel = QtWidgets.QPushButton(self.verticalLayoutWidget)
        self.pushButton_updateModel.setObjectName("pushButton_updateModel")
        self.horizontalLayout_4.addWidget(self.pushButton_updateModel)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem1)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.ConsoleWidget = ConsoleWidget(self.tab)
        self.ConsoleWidget.setEnabled(True)
        self.ConsoleWidget.setGeometry(QtCore.QRect(10, 220, 781, 661))
        self.ConsoleWidget.setObjectName("ConsoleWidget")
        self.label_pushedVariables = QtWidgets.QLabel(self.tab)
        self.label_pushedVariables.setGeometry(QtCore.QRect(330, 30, 461, 101))
        self.label_pushedVariables.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_pushedVariables.setObjectName("label_pushedVariables")
        self.label_pushedVariables0 = QtWidgets.QLabel(self.tab)
        self.label_pushedVariables0.setGeometry(QtCore.QRect(330, 10, 141, 16))
        self.label_pushedVariables0.setObjectName("label_pushedVariables0")
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.verticalLayoutWidget_2 = QtWidgets.QWidget(self.tab_2)
        self.verticalLayoutWidget_2.setGeometry(QtCore.QRect(50, 20, 721, 831))
        self.verticalLayoutWidget_2.setObjectName("verticalLayoutWidget_2")
        self.verticalLayout_inTab2 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_2)
        self.verticalLayout_inTab2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_inTab2.setObjectName("verticalLayout_inTab2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem2)
        self.pushButton_getSignal = QtWidgets.QPushButton(self.verticalLayoutWidget_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.pushButton_getSignal.setFont(font)
        self.pushButton_getSignal.setObjectName("pushButton_getSignal")
        self.horizontalLayout_2.addWidget(self.pushButton_getSignal)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem3)
        self.verticalLayout_inTab2.addLayout(self.horizontalLayout_2)
        self.MplWidget = MplWidget(self.verticalLayoutWidget_2)
        self.MplWidget.setObjectName("MplWidget")
        self.verticalLayout_inTab2.addWidget(self.MplWidget)
        self.tabWidget.addTab(self.tab_2, "")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 800, 21))
        self.menubar.setObjectName("menubar")
        self.menuLoad = QtWidgets.QMenu(self.menubar)
        self.menuLoad.setObjectName("menuLoad")
        self.menuTheme = QtWidgets.QMenu(self.menubar)
        self.menuTheme.setObjectName("menuTheme")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionLocate = QtWidgets.QAction(MainWindow)
        self.actionLocate.setObjectName("actionLocate")
        self.actionDark = QtWidgets.QAction(MainWindow)
        self.actionDark.setObjectName("actionDark")
        self.actionLight = QtWidgets.QAction(MainWindow)
        self.actionLight.setObjectName("actionLight")
        self.menuLoad.addAction(self.actionLocate)
        self.menuTheme.addAction(self.actionDark)
        self.menuTheme.addAction(self.actionLight)
        self.menubar.addAction(self.menuLoad.menuAction())
        self.menubar.addAction(self.menuTheme.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.comboBox_MachineType.setItemText(0, _translate("MainWindow", "Synchronous Machine"))
        self.comboBox_MachineType.setItemText(1, _translate("MainWindow", "Induction Machine"))
        self.label_npd.setText(_translate("MainWindow", "Number of Poles"))
        self.label_npd_2.setText(_translate("MainWindow", "Rated Current [Arms]"))
        self.label_npd_3.setText(_translate("MainWindow", "Rated Power [W]"))
        self.label_npd_4.setText(_translate("MainWindow", "Rated Speed [rpm]"))
        self.lineEdit_npp.setText(_translate("MainWindow", "0"))
        self.lineEdit_RatedCurrent.setText(_translate("MainWindow", "0"))
        self.lineEdit_RatedPower.setText(_translate("MainWindow", "0"))
        self.lineEdit_RatedSpeed.setText(_translate("MainWindow", "0"))
        self.pushButton_updateModel.setText(_translate("MainWindow", "Update Model"))
        self.label_pushedVariables.setText(_translate("MainWindow", "None"))
        self.label_pushedVariables0.setText(_translate("MainWindow", "Variables Pushed qtConsole: "))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("MainWindow", "Name Plate Data"))
        self.pushButton_getSignal.setText(_translate("MainWindow", "Generate\n"
"Signals"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("MainWindow", "Plots"))
        self.menuLoad.setTitle(_translate("MainWindow", "Load"))
        self.menuTheme.setTitle(_translate("MainWindow", "Theme"))
        self.actionLocate.setText(_translate("MainWindow", "Json File"))
        self.actionDark.setText(_translate("MainWindow", "Dark"))
        self.actionLight.setText(_translate("MainWindow", "Light"))
from consolewidget import ConsoleWidget
from mplwidget import MplWidget

# from emachinery.gui.consolewidget import ConsoleWidget
# from emachinery.gui.mplwidget import MplWidget


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())



# 参考：Power = Speed Times Force 总结版！.afx
import math
from dataclasses import dataclass

@dataclass
class ElectricMachinery:
    NUMBER_OF_POLE_PAIRS : int
    RATED_CURRENT_RMS : float
    RATED_POWER_WATT : float
    RATED_SPEED_RPM : float 
    name : str = 'nameless'

    def __post_init__(self):

        this = self

        # Omega
        this.RATED_RATED_SPEED_REV_PER_SEC = self.RATED_SPEED_RPM / 60 
        this.RATED_RATED_SPEED_RAD_PER_SEC = this.RATED_RATED_SPEED_REV_PER_SEC * (2*math.pi)

        # Tem = KT * IN = PW / Omega
        this.RATED_TORQUE = self.RATED_POWER_WATT / this.RATED_RATED_SPEED_RAD_PER_SEC
        # KT = 1.5 * npp * KE = Tem / IN
        this.TORQUE_CONSTANT_Nm_PER_Arms  = this.RATED_TORQUE / (self.RATED_CURRENT_RMS)
        this.TORQUE_CONSTANT_Nm_PER_Apeak = this.RATED_TORQUE / (self.RATED_CURRENT_RMS*1.414)

        # KE = UN / (Omega*npp)
        # unit is volt*sec where 'sec' here is in fact 1 / (rad/sec)---do note rad/sec means electrical speed.
        this.AMPL_INVARIANT_BACK_EMF_CONSTANT_VS    = AMPL_INVARIANT_PM_FLUX_LINKAGE_Wb  = this.TORQUE_CONSTANT_Nm_PER_Apeak / 1.5 / self.NUMBER_OF_POLE_PAIRS
        this.AMPL_INVARIANT_BACK_EMF_CONSTANT_VrmsS                                      = this.AMPL_INVARIANT_BACK_EMF_CONSTANT_VS / 1.414
        this.POWER_INVARIANT_BACK_EMF_CONSTANT_VS   = POWER_INVARIANT_PM_FLUX_LINKAGE_Wb = this.TORQUE_CONSTANT_Nm_PER_Apeak / self.NUMBER_OF_POLE_PAIRS

        # KE
        # Convert electrical speed rad/sec to mechanical speed r/min
        this.AMPL_INVARIANT_BACK_EMF_CONSTANT_MV_PER_RPM    = this.AMPL_INVARIANT_BACK_EMF_CONSTANT_VS    * 1e3 / (1.0/self.NUMBER_OF_POLE_PAIRS/2/math.pi*60)
        this.AMPL_INVARIANT_BACK_EMF_CONSTANT_MVrms_PER_RPM = this.AMPL_INVARIANT_BACK_EMF_CONSTANT_VrmsS * 1e3 / (1.0/self.NUMBER_OF_POLE_PAIRS/2/math.pi*60)

        # E (from aplitude-invariant Clarke transform)
        this.BACK_EMF_V    = 1e-3 * this.AMPL_INVARIANT_BACK_EMF_CONSTANT_MV_PER_RPM * self.RATED_SPEED_RPM
        this.BACK_EMF_Vrms = 1e-3 * this.AMPL_INVARIANT_BACK_EMF_CONSTANT_MV_PER_RPM * self.RATED_SPEED_RPM / 1.414

        # Linear Machine Quantities
        if False:
            # Below is valid for linear motor

            # 磁铁同电极距离（N极到N极）
            this.ELECTRICAL_NORTH_NORTH_PITCH_MM = 30
            # 一台直线电机的跨度包含有 npp 个同电极距离
            this.MECHANICAL_ONE_CYCLE_TRAVLE_MM = this.ELECTRICAL_NORTH_NORTH_PITCH_MM * self.NUMBER_OF_POLE_PAIRS
            # 如果把这台直线电机掰弯成一个圆，那么其半径为
            this.RADIUS_MM = this.MECHANICAL_ONE_CYCLE_TRAVLE_MM / (2*math.pi)
            # 额定的推力为
            this.RATED_FORCE = this.RATED_TORQUE / (RADIUS_MM*1e-3)
            # 推力系数为
            this.FORCE_CONSTANT_N_PER_Arms  = this.RATED_FORCE / self.RATED_CURRENT_RMS
            this.FORCE_CONSTANT_N_PER_Apeak = this.RATED_FORCE / (self.RATED_CURRENT_RMS*1.414)
            # 电机直线速度
            this.RATED_SPEED_MM_PER_SEC = self.RATED_SPEED_RPM / 60 * (this.ELECTRICAL_NORTH_NORTH_PITCH_MM*self.NUMBER_OF_POLE_PAIRS)

        print('---------\n',
        f'{this.RATED_TORQUE:.4f} Nm\n',
        f'{this.TORQUE_CONSTANT_Nm_PER_Arms:.3f} Nm/Arms\n',
        f'{this.AMPL_INVARIANT_BACK_EMF_CONSTANT_VS:g}, Vs\n',
        f'直流伺服用：{this.AMPL_INVARIANT_BACK_EMF_CONSTANT_MV_PER_RPM:.3f} mV/rpm\n',
        f'交流伺服用：{this.AMPL_INVARIANT_BACK_EMF_CONSTANT_MVrms_PER_RPM:.3f} mVrms/rpm\n',
        f'直流伺服用：{this.BACK_EMF_V:.3f} V\n',
        f'交流伺服用：{this.BACK_EMF_Vrms:.3f} Vrms\n',
        # f'{this.RATED_SPEED_MM_PER_SEC} mm/s\n',
            sep='\t')

if __name__ == '__main__':
    em = ElectricMachinery( NUMBER_OF_POLE_PAIRS = 4,
                                       RATED_CURRENT_RMS = 12.8,
                                       RATED_POWER_WATT = 400,
                                       RATED_SPEED_RPM = 3000
        )



# https://stackoverflow.com/questions/32035251/displaying-latex-in-pyqt-pyside-qtablewidget

import sys
from pylab import plt, mpl
from matplotlib.backends.backend_agg import FigureCanvasAgg
from PyQt5 import QtGui, QtCore, QtWidgets

mpl.rcParams['mathtext.fontset'] = 'stix'
mpl.rcParams['font.family'] = 'STIXGeneral'

def mathTex_to_QPixmap(mathTex, fs, fontcolor='black'):

    #---- set up a mpl figure instance ----

    fig = plt.figure()
    fig.patch.set_facecolor('none')
    fig.set_canvas(FigureCanvasAgg(fig))
    renderer = fig.canvas.get_renderer()

    #---- plot the mathTex expression ----

    ax = fig.add_axes([0, 0, 1, 1])
    ax.axis('off')
    ax.patch.set_facecolor('none')
    t = ax.text(0, 0, mathTex, ha='left', va='bottom', fontsize=fs, color=fontcolor)

    #---- fit figure size to text artist ----

    fwidth, fheight = fig.get_size_inches()
    fig_bbox = fig.get_window_extent(renderer)

    text_bbox = t.get_window_extent(renderer)

    tight_fwidth = text_bbox.width * fwidth / fig_bbox.width
    tight_fheight = text_bbox.height * fheight / fig_bbox.height

    fig.set_size_inches(tight_fwidth, tight_fheight)

    #---- convert mpl figure to QPixmap ----

    buf, size = fig.canvas.print_to_buffer()
    qimage = QtGui.QImage.rgbSwapped(QtGui.QImage(buf, size[0], size[1],
                                                  QtGui.QImage.Format_ARGB32))
    qpixmap = QtGui.QPixmap(qimage)

    return qpixmap

class LaTeX_Repo(object):
    def __init__(self, fs=18, fontcolor='white'):
        self.qpixmap_CLKP = mathTex_to_QPixmap(r'${\rm curK}_P = L \times \mathrm{curBW}$', fs=fs, fontcolor=fontcolor)
        self.qpixmap_CLKI = mathTex_to_QPixmap(r'${\rm curK}_I = {R}/{L}$', fs=fs, fontcolor=fontcolor)
        self.qpixmap_VLKP = mathTex_to_QPixmap(r'$\mathrm{velK}_P=\frac{\mathrm{curBW}}{\delta}\frac{J_{\mathrm{total}}}{n_{pp}}\frac{1}{\left( \frac{3}{2}n_{pp}K_E \right)}$', fs=fs, fontcolor=fontcolor)
        self.qpixmap_VLKI = mathTex_to_QPixmap(r'$\mathrm{velK}_I=\frac{\mathrm{curBW}}{\delta ^2}$', fs=fs, fontcolor=fontcolor)
        self.qpixmap_Note1 = mathTex_to_QPixmap(r'$\mathrm{Velocity}~\mathrm{PI}~\mathrm{Regulator}~\mathrm{Input}:~\mathrm{Velocity~Control~Error}~\left[ \mathrm{elec}.\mathrm{rad}/\sec \right] $', fs=fs, fontcolor=fontcolor)
        self.qpixmap_Note2 = mathTex_to_QPixmap(r'$\mathrm{Velocity}~\mathrm{PI}~\mathrm{Regulator}~\mathrm{Output}:~\mathrm{Current~Command}~\left[ \mathrm{Apeak} \right] $', fs=fs, fontcolor=fontcolor)
        self.qpixmap_Note3 = mathTex_to_QPixmap(r'${\rm Series~Type~PI~Regulator}:~i_{q}^{*}=\left( \mathrm{velK}_P+\frac{\mathrm{velK}_P\mathrm{velK}_I}{p} \right) \left( \omega ^*-\omega \right) $', fs=fs, fontcolor=fontcolor)

if __name__ == '__main__':
    
    mathTex_to_QPixmap('$C_{soil}=(1 - n) C_m + \\theta_w C_w$', fs=16)



import pandas as pd
from pylab import plt, np
from pylab import fft
import math
import os
# dot_dat_file_dir = os.path.dirname(os.path.realpath(__file__)) + '/'


def find_nearest(array, value):
    array = np.asarray(array)
    idx = (np.abs(array - value)).argmin()
    return idx, array[idx]

def analyze(dot_dat_file_dir, motor_dict, sweepFreq_dict, bool_use_commanded_freq=True):

    if(not os.path.exists(dot_dat_file_dir)):
        print('Cannot locate:', dot_dat_file_dir)
        return None

    # read data as Data Frame and process
    # df_info     = pd.read_csv(dot_dat_file_dir+'dat/info.dat', na_values = ['1.#QNAN', '-1#INF00', '-1#IND00'])
    df_profiles = pd.read_csv(dot_dat_file_dir, na_values = ['1.#QNAN', '-1#INF00', '-1#IND00'])

    # print(dot_dat_file_dir)
    # print(df_profiles)

    no_samples = df_profiles.shape[0]
    no_traces  = df_profiles.shape[1]

    Ts = motor_dict['CL_TS']
    # print('Ts =', Ts)

    # print('Simulated time: %g s.'%(no_samples * Ts * motor_dict['DOWN_SAMPLE']), 'Key list:', sep='\n')
    # for key in df_profiles.keys():
    #     print('\t', key)

    # Unpack as Series
    t = np.arange(1, no_samples+1) * motor_dict['DOWN_SAMPLE'] * Ts
    time  = t
    if sweepFreq_dict["SWEEP_FREQ_C2V"]:
        # C2V
        key_ref = 'CTRL.iq_cmd'; # note this is q-axis current command instead of measured q-axis current
        key_qep = 'sm.omg_elec*RAD_PER_SEC_2_RPM';
        x_ref = df_profiles[key_ref] # [Apk]
        x_qep = df_profiles[key_qep]/60*2*np.pi*motor_dict["n_pp"] # [rpm] -> [elec.rad/s]
    elif sweepFreq_dict["SWEEP_FREQ_C2C"]:
        # C2C
        key_ref = 'CTRL.id_cmd';
        key_qep = 'ACM.id';
        x_ref = df_profiles[key_ref] # [Apk] 
        x_qep = df_profiles[key_qep] # [Apk]
    else:
        # V2V
        key_ref = 'ACM.rpm_cmd';
        key_qep = 'sm.omg_elec*RAD_PER_SEC_2_RPM';
        x_ref = df_profiles[key_ref] # [rpm] # 闭环系统传递函数分析单时候，输入输出的单位是一样的，求传递函数的时候一除，就算用的是rpm也都无所谓了（虽然理论上是按elec.rad/s设计的）
        x_qep = df_profiles[key_qep] # [rpm]

    # Basic DFT parameters
    # N = df.shape[0]
    samplingFreq = 1/Ts
    EndTime = t[-1]
    #     print('End Time:', EndTime, 's')
    # print('Sampling Frequency:', samplingFreq*1e-3, 'kHz')
    #     # print('Number of Points:', N)
    #     print()

    # Plot signal in time domain
    for index, value in enumerate(x_ref):
        if value!=x_ref.iloc[0]:
            index_begin = index
            time_begin = index*Ts
            break
    for index, value in enumerate(x_ref[::-1]):
        if value!=x_ref.iloc[-1]:
            index_end = -index
            time_end = EndTime - index*Ts
            break
    # print('index_begin', index_begin)
    # print('index_end', index_end)
    # print('time_begin:', time_begin, 's')
    # print('time_end', time_end,   's')
    # time  = time [index_begin:index_end]
    # x_ref = x_ref[index_begin:index_end]
    # x_qep = x_qep[index_begin:index_end]
    # plt.figure(100, figsize=(20,4))
    # plt.title('Origianl Signal')
    # plt.xlabel('Time [s]')
    # plt.ylabel('Speed [elec.rad/s]')
    # plt.plot(time, x_ref, label='ref')
    # # plt.figure(101)
    # plt.plot(time, x_qep, label='qep')
    # plt.show()
    # print('----------------')
    # print('xref')
    # for el in x_ref.values:
    #     print(el)
    # print('xqep')
    # for el in x_qep.values:
    #     print(el)
    # # # plt.savefig(r'C:\Users\horyc\Desktop\test.png')
    # quit()

    #     # plt.xlim([0, 8/target_Hz])
    #     print()
    #     print('Max reference speed:', max(x_ref))
    #     print('Max measured speed:', max(x_qep))
    #     print('Min reference speed:', min(x_ref))
    #     print('Min measured speed:', min(x_qep))


    #     print()
    #     TimeSpan = time.iloc[-1]
    #     print('Time Span:', TimeSpan, 's')

    list_qep_max_amplitude = []
    list_qep_max_frequency = []
    list_qep_max_phase = []
    list_ref_max_amplitude = []
    list_ref_max_frequency = []
    list_ref_max_phase = []
    list_phase_difference = []


    list_commanded_frequency = []

    index_single_tone_begin = 0
    index_single_tone_end = 0
    # max_freq = 5 # debug
    # for freq in range(2, max_freq): # datum point at 1 Hz and last point are absent in experiment
    for freq in range(sweepFreq_dict['init_freq'], sweepFreq_dict['max_freq']):
        period = 1.0/freq # 1.0 Duration for each frequency
        index_single_tone_begin = index_single_tone_end
        index_single_tone_end = index_single_tone_begin + int(period/Ts)

        if False:
            # use only steady state profile for this frequency
            ST_time  =  time[int(index_single_tone_end-0.1*(index_single_tone_end-index_single_tone_begin)):index_single_tone_end]
            ST_x_ref = x_ref[int(index_single_tone_end-0.1*(index_single_tone_end-index_single_tone_begin)):index_single_tone_end]
            ST_x_qep = x_qep[int(index_single_tone_end-0.1*(index_single_tone_end-index_single_tone_begin)):index_single_tone_end]
        else:
            # use complete profile for this frequency
            ST_time  =  time[index_single_tone_begin:index_single_tone_end]
            ST_x_ref = x_ref[index_single_tone_begin:index_single_tone_end]
            ST_x_qep = x_qep[index_single_tone_begin:index_single_tone_end]
            # plt.plot(ST_time, ST_x_ref)
            # plt.plot(ST_time, ST_x_qep)

        # print(freq, index_single_tone_begin, index_single_tone_end)

        if(len(ST_x_ref))<1:
            print('sweep frequency too high: no data')
            break

        x_ref_dft = fft(ST_x_ref)
        x_qep_dft = fft(ST_x_qep)

        # Do DFT (Raw)
        N = len(ST_time)
        # plt.figure(1, figsize=(20,4))
        # plt.plot(abs(x_ref_dft)/N, '.--', alpha=0.5, label='x_ref-dft');
        # plt.plot(abs(x_qep_dft)/N, '.--', alpha=0.5, label='x_qep-dft');
        # #     plt.legend(loc='center')

        # Convert raw DFT results into human-friendly forms
        resolution = samplingFreq/N # [Hz]
        Neff = math.ceil(N/2) # number of effective points
                              # 其实理论上来说，这里是比较复杂的，当N为偶数的时候，奈奎斯特频率就是采样频率的二分之一？当N为奇数的时候，还会多出一个分量，这个分量和直流分量是一对，具体我忘了……可能有错
        x_ref_hat = np.append(x_ref_dft[0]/N, 2*x_ref_dft[1:Neff+1]/N)  # 原始复数dft结果（双边变单边，除了直流分量，其他分量全部要乘以2）
        x_qep_hat = np.append(x_qep_dft[0]/N, 2*x_qep_dft[1:Neff+1]/N)

        # # Plot DFT for human to read
        # plt.figure(2, figsize=(20,4))
        # plt.plot(np.array(list(range(0, Neff+1)))*resolution, abs(x_ref_hat), '--s', alpha=0.5, label='ref');
        # plt.plot(np.array(list(range(0, Neff+1)))*resolution, abs(x_qep_hat), '--o', alpha=0.5, label='qep');

        # qep related data collection
        max_amplitude = max(abs(x_qep_hat));      list_qep_max_amplitude.append(max_amplitude)
        max_index     = np.argmax(abs(x_qep_hat))
        max_frequency = (max_index+0)*resolution; list_qep_max_frequency.append(max_frequency)
        # qep phase
        max_complexNumber = x_qep_hat[max_index]
        max_phase = np.arctan2(max_complexNumber.imag, max_complexNumber.real); list_qep_max_phase.append(max_phase)
        qep_complexNumber = max_complexNumber

        #     print(f'Frequency Resolution: {resolution:.2f} Hz', end=' | ')
        #     print(f'Max Amplitude: {max_amplitude:.2f} rpm', end=' | ')
        #     print(f'Corresponding Frequency: {max_frequency:.2f} Hz')

        # ref related data collection
        max_amplitude = max(abs(x_ref_hat));      list_ref_max_amplitude.append(max_amplitude)
        max_index     = np.argmax(abs(x_ref_hat))
        max_frequency = (max_index+0)*resolution; list_ref_max_frequency.append(max_frequency)
        # ref phase
        max_complexNumber = x_ref_hat[max_index]
        max_phase = np.arctan2(max_complexNumber.imag, max_complexNumber.real); list_ref_max_phase.append(max_phase)
        ref_complexNumber = max_complexNumber

        # phase difference
        list_phase_difference.append( -np.arccos( (qep_complexNumber.real*ref_complexNumber.real+qep_complexNumber.imag*ref_complexNumber.imag)
                                                 /(abs(ref_complexNumber)*abs(qep_complexNumber)) )/np.pi*180 )
        # commanded frequency
        list_commanded_frequency.append(freq)

    closed_loop_transfer_function = [qep/ref for ref, qep in zip(list_ref_max_amplitude, list_qep_max_amplitude)]
    CL_VL_TF = [20*np.log10(el) for el in closed_loop_transfer_function]

    if bool_use_commanded_freq == True:
        return CL_VL_TF, list_phase_difference, list_commanded_frequency, sweepFreq_dict['max_freq']
    else:
        return CL_VL_TF, list_phase_difference, list_qep_max_frequency, sweepFreq_dict['max_freq']

# def plot()
#     plt.figure(4, figsize=(20,8))
#     closed_loop_transfer_function = [qep/ref for ref, qep in zip(list_ref_max_amplitude, list_qep_max_amplitude)]

#     CL_VL_TF_ABS = [20*np.log10(el) for el in closed_loop_transfer_function]
#     if bool_use_commanded_freq == True:
#         plt.plot(list_commanded_frequency, CL_VL_TF_ABS, '--.', label=fname)
#     else:
#         plt.plot(list_qep_max_frequency, CL_VL_TF_ABS, '--.', label=fname)


#     print(key_ref, key_qep)
#     if 'speed' in key_ref:
#         index, value = find_nearest(CL_VL_TF_ABS, -3) # find -3dB freq
#         VLBW = list_qep_max_frequency[index]
#         plt.text(VLBW, -5, f'{VLBW:.0f} Hz', color='red', fontsize=20)
#         # plt.xticks(range(0,max_freq+1, int(max_freq/20)))
#         plt.plot([0,max_freq], [-3, -3], 'k--')
#         plt.ylabel('Velocity Closed-loop transfer function amplitude [dB]')
#     else:
#         if 'id' not in key_qep:
#             plt.ylabel('C2V [dB] (elec.rad/s/A)')
#         else:
#             plt.ylabel('Current Closed-loop transfer function amplitude [dB]')

#     # plt.text(np.log10(VLBW), -5, f'{VLBW:.0f} Hz', fontsize=20)
#     # plt.plot(CL_VL_TF_FREQ, CL_VL_TF_ABS, '--.', label=fname)
#     # plt.plot([0,np.log10(max_freq)], [-3, -3], 'k--')

#     plt.xscale('log')
#     plt.xlabel('Frequency [Hz]')
#     #plt.ylabel('Closed-loop transfer function amplitude [1]')
#     # plt.xlim([0,50])
#     # plt.ylim([-10,0])
#     # plt.grid()
#     plt.legend()

def folder(dot_dat_file_dir, motor_dict, data_fname_prefix='default', **kwarg):
    active_data_fnames = []
    max_freq_list = []
    for fname in os.listdir(dot_dat_file_dir+'../_simulator/dat/'):
        if data_fname_prefix in fname:
            active_data_fnames.append(fname)
            max_freq_list.append(int(fname[fname.find('@')+1:fname.find('Hz')]))
    # print(max_freq_list)
    # quit()

    # Target file name
    for fname, max_freq in zip(active_data_fnames, max_freq_list):
        analyze(dot_dat_file_dir, fname, max_freq, ad, **kwarg)

    # print('Measured bandwidth is', VLBW, 'Hz')



# ------------------------------------------------------
# -------------------- mplwidget.py --------------------
# ------------------------------------------------------
from PyQt5.QtWidgets import QWidget, QVBoxLayout

from matplotlib.backends.backend_qt5agg import FigureCanvas

from matplotlib.figure import Figure

from pylab import plt

class MplWidget(QWidget):
    
    def __init__(self, parent = None):

        QWidget.__init__(self, parent)
        
        self.canvas = FigureCanvas(Figure(tight_layout=True))
        
        vertical_layout = QVBoxLayout()
        vertical_layout.addWidget(self.canvas)
        
        self.setLayout(vertical_layout)

        self.canvas.axes = None #self.canvas.figure.add_subplot(111)


        # add new animation feature
        def on_press(event):
            if event.key.isspace():
                if anim.running:
                    anim.event_source.stop()
                else:
                    anim.event_source.start()
                anim.running ^= True
        self.canvas.mpl_connect('key_press_event', on_press)





import json
from collections import OrderedDict
import pandas
import os

# 定义全局Excel表名列表
sheetNameList = [u'基本参数', u'参数辨识']

# 写 json->excel
if __name__ == '!__main__':
    with open('machine_specification.json', 'r', encoding='utf-8') as f:
        d = json.load(f, object_pairs_hook=OrderedDict) # https://stackoverflow.com/questions/10844064/items-in-json-object-are-out-of-order-using-json-dumps/23820416
        # print(type(d))
        # print(json.dumps(d, indent=4, ensure_ascii=False))

    if False: # 显示写法
        基本参数字典 = OrderedDict()
        参数辨识字典 = OrderedDict()
        for motorName, details in d.items():
            基本参数字典[motorName] = details['基本参数']
            参数辨识字典[motorName] = details['参数辨识']
        with pandas.ExcelWriter('ACMInfo.xlsx') as writer:
            pandas.DataFrame(基本参数字典).to_excel(writer, sheet_name='基本参数')
            pandas.DataFrame(参数辨识字典).to_excel(writer, sheet_name='参数辨识')
    else:  # 隐式写法
        # 按Excel表名列表，初始化表字典
        for sheetName in sheetNameList:
            exec(f"{sheetName}字典 = OrderedDict()")
        # 按表赋值
        for motorName, details in d.items():
            for sheetName in sheetNameList:
                exec(f"{sheetName}字典[motorName] = details['{sheetName}']")
        # 写到硬盘
        with pandas.ExcelWriter('ACMInfo.xlsx') as writer:
            for sheetName in sheetNameList:
                exec(f"pandas.DataFrame({sheetName}字典).to_excel(writer, sheet_name='{sheetName}')")
    quit()


# 读：excel->json
if __name__ == '__main__':

    if False: # 显式写法
        df = pandas.read_excel(open('ACMInfo.xlsx', 'rb'), sheet_name=u'基本参数')
        基本参数字典 = df.set_index('代号(序列号)').to_dict(into=OrderedDict)

        df = pandas.read_excel(open('ACMInfo.xlsx', 'rb'), sheet_name=u'参数辨识')
        参数辨识字典 = df.set_index('代号(序列号)').to_dict(into=OrderedDict)

        写硬盘字典 = OrderedDict()
        for k, _ in 基本参数字典.items():
            # print(k)
            # 写硬盘字典[k] = { '基本参数':基本参数字典[k], 
            #                  '参数辨识':参数辨识字典[k] 
            #                 }
            写硬盘字典[k] = OrderedDict([('基本参数', 基本参数字典[k])])
            try:
                写硬盘字典[k].update(OrderedDict([('参数辨识', 参数辨识字典[k])]))
            except KeyError as e:
                print(e)
                print(f'【警告】参数辨识的表里没有{k}这款电机的数据')

    else: # 隐式写法

        # dataframe -> dict
        for sheetName in sheetNameList:
            df = pandas.read_excel(open('ACMInfo.xlsx', 'rb'), sheet_name=sheetName)
            exec(f"{sheetName}字典 = df.set_index('代号(序列号)').to_dict(into=OrderedDict)")

        写硬盘字典 = OrderedDict()
        for k, _ in 基本参数字典.items():
            print(k)
            try:
                写硬盘字典[k] = OrderedDict([ eval(f"('{sheetName}', {sheetName}字典[k])") for sheetName in sheetNameList ])
            except KeyError as e:
                print(f'\t【警告】{sheetName}的表里没有“{k}”这款电机的数据。')

    with open('machine_specification-auto.json', 'w', encoding='utf-8') as f:
        json.dump(写硬盘字典, f, ensure_ascii=False, indent=4)

class MotorJson(object):
    """docstring for MotorJson"""
    def __init__(self):
        # with open('machine_specification-auto.json', 'r', encoding='utf-8') as f:
        with open(os.path.dirname(__file__)+'/machine_specification-auto.json', 'r', encoding='utf-8') as f:
            self.d = json.load(f, object_pairs_hook=OrderedDict) # https://stackoverflow.com/questions/10844064/items-in-json-object-are-out-of-order-using-json-dumps/23820416




# https://stackoverflow.com/questions/16732379/stop-start-pause-in-python-matplotlib-animation
import matplotlib.pyplot as plt
import matplotlib.animation as ani

fig, ax = plt.subplots()
txt = fig.text(0.5,0.5,'0')

def update_time():
    t = 0
    t_max = 10
    while t<t_max:
        t += anim.direction
        yield t

def update_plot(t):
    txt.set_text('%s'%t)
    # plt.gca().clear()
    plt.plot(t, t**2, '.')
    return txt

def on_press(event):
    if event.key.isspace():
        if anim.running:
            anim.event_source.stop()
        else:
            anim.event_source.start()
        anim.running ^= True
    elif event.key == 'left':
        anim.direction = -1
    elif event.key == 'right':
        anim.direction = +1

    # Manually update the plot
    if event.key in ['left','right']:
        t = anim.frame_seq.__next__()
        update_plot(t)
        plt.draw()

fig.canvas.mpl_connect('key_press_event', on_press)
anim = ani.FuncAnimation(fig, update_plot, frames=update_time,
                         interval=100, repeat=True)
anim.running = True
anim.direction = +1
plt.show()



# https://stackoverflow.com/questions/11513132/embedding-ipython-qt-console-in-a-pyqt-application
from qtconsole.qt import QtGui
from qtconsole.rich_jupyter_widget import RichJupyterWidget
from qtconsole.inprocess import QtInProcessKernelManager

# import logging

from PyQt5.QtWidgets import QWidget

class ConsoleWidget(RichJupyterWidget):

    # def __init__(self, customBanner=None, *args, **kwargs):
    def __init__(self, parent=None, *args, **kwargs):
        QWidget.__init__(self, parent)

        super(ConsoleWidget, self).__init__(*args, **kwargs)

        # if customBanner is not None:
        #     self.banner = customBanner
        self.banner = "This is an embedded qtconsole.\nSuggested commands:\n\tvars(emy)\n\n"
                    # [attr for attr in dir(emy) if not callable(getattr(emy, attr)) and not attr.startswith('__')]
                    # https://stackoverflow.com/questions/1398022/looping-over-all-member-variables-of-a-class-in-python

        self.font_size = 6
        self.kernel_manager = kernel_manager = QtInProcessKernelManager()

        kernel_manager.start_kernel(show_banner=False)
        # kernel_manager.kernel.log.setLevel(logging.CRITICAL) # 
        kernel_manager.kernel.gui = 'qt'
        self.kernel_client = kernel_client = self._kernel_manager.client()
        kernel_client.start_channels()

        def stop():
            kernel_client.stop_channels()
            kernel_manager.shutdown_kernel()
            guisupport.get_app_qt().exit()

        self.exit_requested.connect(stop)

    def push_vars(self, variableDict):
        """
        Given a dictionary containing name / value pairs, push those variables
        to the Jupyter console widget
        """
        self.kernel_manager.kernel.shell.push(variableDict)

    def clear(self):
        """
        Clears the terminal
        """
        self._control.clear()

        # self.kernel_manager

    def print_text(self, text):
        """
        Prints some plain text to the console
        """
        self._append_plain_text(text)

    def execute_command(self, command):
        """
        Execute a command in the frame of the console widget
        """
        self._execute(command, False)


if __name__ == '__main__':

    app = QtGui.QApplication([])
    widget = ConsoleWidget()
    widget.show()
    app.exec_()




from emachinery.gui.consolewidget import ConsoleWidget
from emachinery.gui.mplwidget import MplWidget
from emachinery.gui.qcodeeditor import QCodeEditor

# from consolewidget import ConsoleWidget
# from mplwidget import MplWidget
# from qcodeeditor import QCodeEditor
# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainWindow_v2.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1712, 1215)
        MainWindow.setMinimumSize(QtCore.QSize(0, 0))
        MainWindow.setStyleSheet("")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout(self.centralwidget)
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.scrollArea_CBS_Left = QtWidgets.QScrollArea(self.centralwidget)
        self.scrollArea_CBS_Left.setStyleSheet("")
        self.scrollArea_CBS_Left.setWidgetResizable(True)
        self.scrollArea_CBS_Left.setObjectName("scrollArea_CBS_Left")
        self.scrollAreaWidgetContents_3 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_3.setGeometry(QtCore.QRect(0, 0, 842, 1154))
        self.scrollAreaWidgetContents_3.setObjectName("scrollAreaWidgetContents_3")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_3)
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.tabWidget = QtWidgets.QTabWidget(self.scrollAreaWidgetContents_3)
        self.tabWidget.setMinimumSize(QtCore.QSize(500, 800))
        self.tabWidget.setStyleSheet("")
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.verticalLayoutWidget = QtWidgets.QWidget(self.tab)
        self.verticalLayoutWidget.setGeometry(QtCore.QRect(10, 10, 288, 218))
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.verticalLayoutWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.comboBox_MachineType = QtWidgets.QComboBox(self.verticalLayoutWidget)
        self.comboBox_MachineType.setObjectName("comboBox_MachineType")
        self.comboBox_MachineType.addItem("")
        self.comboBox_MachineType.addItem("")
        self.verticalLayout.addWidget(self.comboBox_MachineType)
        self.comboBox_MachineName = QtWidgets.QComboBox(self.verticalLayoutWidget)
        self.comboBox_MachineName.setObjectName("comboBox_MachineName")
        self.verticalLayout.addWidget(self.comboBox_MachineName)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label_npd = QtWidgets.QLabel(self.verticalLayoutWidget)
        self.label_npd.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_npd.setObjectName("label_npd")
        self.verticalLayout_2.addWidget(self.label_npd)
        self.label_npd_2 = QtWidgets.QLabel(self.verticalLayoutWidget)
        self.label_npd_2.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_2.setObjectName("label_npd_2")
        self.verticalLayout_2.addWidget(self.label_npd_2)
        self.label_npd_3 = QtWidgets.QLabel(self.verticalLayoutWidget)
        self.label_npd_3.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_3.setObjectName("label_npd_3")
        self.verticalLayout_2.addWidget(self.label_npd_3)
        self.label_npd_4 = QtWidgets.QLabel(self.verticalLayoutWidget)
        self.label_npd_4.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_4.setObjectName("label_npd_4")
        self.verticalLayout_2.addWidget(self.label_npd_4)
        self.horizontalLayout.addLayout(self.verticalLayout_2)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.lineEdit_npp = QtWidgets.QLineEdit(self.verticalLayoutWidget)
        self.lineEdit_npp.setObjectName("lineEdit_npp")
        self.verticalLayout_3.addWidget(self.lineEdit_npp)
        self.lineEdit_RatedCurrent = QtWidgets.QLineEdit(self.verticalLayoutWidget)
        self.lineEdit_RatedCurrent.setObjectName("lineEdit_RatedCurrent")
        self.verticalLayout_3.addWidget(self.lineEdit_RatedCurrent)
        self.lineEdit_RatedPower = QtWidgets.QLineEdit(self.verticalLayoutWidget)
        self.lineEdit_RatedPower.setObjectName("lineEdit_RatedPower")
        self.verticalLayout_3.addWidget(self.lineEdit_RatedPower)
        self.lineEdit_RatedSpeed = QtWidgets.QLineEdit(self.verticalLayoutWidget)
        self.lineEdit_RatedSpeed.setObjectName("lineEdit_RatedSpeed")
        self.verticalLayout_3.addWidget(self.lineEdit_RatedSpeed)
        self.horizontalLayout.addLayout(self.verticalLayout_3)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem)
        self.pushButton_updateModel = QtWidgets.QPushButton(self.verticalLayoutWidget)
        self.pushButton_updateModel.setObjectName("pushButton_updateModel")
        self.horizontalLayout_4.addWidget(self.pushButton_updateModel)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem1)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.ConsoleWidget = ConsoleWidget(self.tab)
        self.ConsoleWidget.setEnabled(True)
        self.ConsoleWidget.setGeometry(QtCore.QRect(10, 220, 781, 661))
        self.ConsoleWidget.setObjectName("ConsoleWidget")
        self.label_pushedVariables = QtWidgets.QLabel(self.tab)
        self.label_pushedVariables.setGeometry(QtCore.QRect(330, 30, 471, 61))
        self.label_pushedVariables.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_pushedVariables.setWordWrap(True)
        self.label_pushedVariables.setObjectName("label_pushedVariables")
        self.label_pushedVariables0 = QtWidgets.QLabel(self.tab)
        self.label_pushedVariables0.setGeometry(QtCore.QRect(330, 10, 141, 16))
        self.label_pushedVariables0.setObjectName("label_pushedVariables0")
        self.tabWidget.addTab(self.tab, "")
        self.tab_5 = QtWidgets.QWidget()
        self.tab_5.setObjectName("tab_5")
        self.groupBox_2 = QtWidgets.QGroupBox(self.tab_5)
        self.groupBox_2.setGeometry(QtCore.QRect(0, 370, 811, 451))
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayoutWidget_8 = QtWidgets.QWidget(self.groupBox_2)
        self.verticalLayoutWidget_8.setGeometry(QtCore.QRect(10, 30, 791, 411))
        self.verticalLayoutWidget_8.setObjectName("verticalLayoutWidget_8")
        self.verticalLayout_16 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_8)
        self.verticalLayout_16.setContentsMargins(2, 0, 2, 0)
        self.verticalLayout_16.setSpacing(1)
        self.verticalLayout_16.setObjectName("verticalLayout_16")
        self.label_qpix_CLKP = QtWidgets.QLabel(self.verticalLayoutWidget_8)
        self.label_qpix_CLKP.setStyleSheet("background: rgb(0, 0, 0)")
        self.label_qpix_CLKP.setText("")
        self.label_qpix_CLKP.setScaledContents(False)
        self.label_qpix_CLKP.setObjectName("label_qpix_CLKP")
        self.verticalLayout_16.addWidget(self.label_qpix_CLKP)
        self.label_qpix_CLKI = QtWidgets.QLabel(self.verticalLayoutWidget_8)
        self.label_qpix_CLKI.setStyleSheet("background: rgb(0,0,0)")
        self.label_qpix_CLKI.setText("")
        self.label_qpix_CLKI.setScaledContents(False)
        self.label_qpix_CLKI.setObjectName("label_qpix_CLKI")
        self.verticalLayout_16.addWidget(self.label_qpix_CLKI)
        self.label_qpix_VLKP = QtWidgets.QLabel(self.verticalLayoutWidget_8)
        self.label_qpix_VLKP.setStyleSheet("background: rgb(0,0,0)")
        self.label_qpix_VLKP.setText("")
        self.label_qpix_VLKP.setScaledContents(False)
        self.label_qpix_VLKP.setObjectName("label_qpix_VLKP")
        self.verticalLayout_16.addWidget(self.label_qpix_VLKP)
        self.label_qpix_VLKI = QtWidgets.QLabel(self.verticalLayoutWidget_8)
        self.label_qpix_VLKI.setStyleSheet("background: rgb(0,0,0)")
        self.label_qpix_VLKI.setText("")
        self.label_qpix_VLKI.setScaledContents(False)
        self.label_qpix_VLKI.setObjectName("label_qpix_VLKI")
        self.verticalLayout_16.addWidget(self.label_qpix_VLKI)
        self.label_qpix_Note1 = QtWidgets.QLabel(self.verticalLayoutWidget_8)
        self.label_qpix_Note1.setStyleSheet("background: rgb(0,0,0)")
        self.label_qpix_Note1.setText("")
        self.label_qpix_Note1.setScaledContents(False)
        self.label_qpix_Note1.setObjectName("label_qpix_Note1")
        self.verticalLayout_16.addWidget(self.label_qpix_Note1)
        self.label_qpix_Note2 = QtWidgets.QLabel(self.verticalLayoutWidget_8)
        self.label_qpix_Note2.setStyleSheet("background: rgb(0,0,0)")
        self.label_qpix_Note2.setText("")
        self.label_qpix_Note2.setScaledContents(False)
        self.label_qpix_Note2.setObjectName("label_qpix_Note2")
        self.verticalLayout_16.addWidget(self.label_qpix_Note2)
        self.label_qpix_Note3 = QtWidgets.QLabel(self.verticalLayoutWidget_8)
        self.label_qpix_Note3.setStyleSheet("background: rgb(0,0,0)")
        self.label_qpix_Note3.setText("")
        self.label_qpix_Note3.setScaledContents(False)
        self.label_qpix_Note3.setObjectName("label_qpix_Note3")
        self.verticalLayout_16.addWidget(self.label_qpix_Note3)
        self.groupBox_3 = QtWidgets.QGroupBox(self.tab_5)
        self.groupBox_3.setGeometry(QtCore.QRect(410, 240, 321, 131))
        self.groupBox_3.setObjectName("groupBox_3")
        self.formLayoutWidget_2 = QtWidgets.QWidget(self.groupBox_3)
        self.formLayoutWidget_2.setGeometry(QtCore.QRect(20, 20, 160, 100))
        self.formLayoutWidget_2.setObjectName("formLayoutWidget_2")
        self.formLayout_2 = QtWidgets.QFormLayout(self.formLayoutWidget_2)
        self.formLayout_2.setContentsMargins(0, 0, 0, 0)
        self.formLayout_2.setObjectName("formLayout_2")
        self.label_12 = QtWidgets.QLabel(self.formLayoutWidget_2)
        self.label_12.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_12.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_12.setObjectName("label_12")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_12)
        self.lineEdit_PC_currentKP = QtWidgets.QLineEdit(self.formLayoutWidget_2)
        self.lineEdit_PC_currentKP.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_PC_currentKP.setReadOnly(True)
        self.lineEdit_PC_currentKP.setObjectName("lineEdit_PC_currentKP")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.lineEdit_PC_currentKP)
        self.label_13 = QtWidgets.QLabel(self.formLayoutWidget_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_13.sizePolicy().hasHeightForWidth())
        self.label_13.setSizePolicy(sizePolicy)
        self.label_13.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_13.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_13.setObjectName("label_13")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_13)
        self.lineEdit_PC_currentKI = QtWidgets.QLineEdit(self.formLayoutWidget_2)
        self.lineEdit_PC_currentKI.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_PC_currentKI.setReadOnly(True)
        self.lineEdit_PC_currentKI.setObjectName("lineEdit_PC_currentKI")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.lineEdit_PC_currentKI)
        self.label_14 = QtWidgets.QLabel(self.formLayoutWidget_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_14.sizePolicy().hasHeightForWidth())
        self.label_14.setSizePolicy(sizePolicy)
        self.label_14.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_14.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_14.setObjectName("label_14")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_14)
        self.lineEdit_PC_speedKP = QtWidgets.QLineEdit(self.formLayoutWidget_2)
        self.lineEdit_PC_speedKP.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_PC_speedKP.setReadOnly(True)
        self.lineEdit_PC_speedKP.setObjectName("lineEdit_PC_speedKP")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.lineEdit_PC_speedKP)
        self.label_15 = QtWidgets.QLabel(self.formLayoutWidget_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_15.sizePolicy().hasHeightForWidth())
        self.label_15.setSizePolicy(sizePolicy)
        self.label_15.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_15.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_15.setObjectName("label_15")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_15)
        self.lineEdit_PC_speedKI = QtWidgets.QLineEdit(self.formLayoutWidget_2)
        self.lineEdit_PC_speedKI.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_PC_speedKI.setReadOnly(True)
        self.lineEdit_PC_speedKI.setObjectName("lineEdit_PC_speedKI")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.lineEdit_PC_speedKI)
        self.groupBox_4 = QtWidgets.QGroupBox(self.tab_5)
        self.groupBox_4.setGeometry(QtCore.QRect(410, 20, 321, 211))
        self.groupBox_4.setObjectName("groupBox_4")
        self.formLayoutWidget = QtWidgets.QWidget(self.groupBox_4)
        self.formLayoutWidget.setGeometry(QtCore.QRect(10, 20, 282, 176))
        self.formLayoutWidget.setObjectName("formLayoutWidget")
        self.formLayout = QtWidgets.QFormLayout(self.formLayoutWidget)
        self.formLayout.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setLabelAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.formLayout.setFormAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.formLayout.setContentsMargins(0, 0, 0, 0)
        self.formLayout.setHorizontalSpacing(6)
        self.formLayout.setObjectName("formLayout")
        self.label_7 = QtWidgets.QLabel(self.formLayoutWidget)
        font = QtGui.QFont()
        font.setItalic(False)
        self.label_7.setFont(font)
        self.label_7.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_7.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_7.setTextFormat(QtCore.Qt.AutoText)
        self.label_7.setAlignment(QtCore.Qt.AlignCenter)
        self.label_7.setObjectName("label_7")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_7)
        self.lineEdit_CLBW = QtWidgets.QLineEdit(self.formLayoutWidget)
        self.lineEdit_CLBW.setFrame(True)
        self.lineEdit_CLBW.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_CLBW.setReadOnly(True)
        self.lineEdit_CLBW.setObjectName("lineEdit_CLBW")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.lineEdit_CLBW)
        self.label_10 = QtWidgets.QLabel(self.formLayoutWidget)
        self.label_10.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_10.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_10.setObjectName("label_10")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_10)
        self.lineEdit_currentKP = QtWidgets.QLineEdit(self.formLayoutWidget)
        self.lineEdit_currentKP.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_currentKP.setReadOnly(True)
        self.lineEdit_currentKP.setObjectName("lineEdit_currentKP")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.lineEdit_currentKP)
        self.label_11 = QtWidgets.QLabel(self.formLayoutWidget)
        self.label_11.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_11.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_11.setObjectName("label_11")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_11)
        self.lineEdit_currentKI = QtWidgets.QLineEdit(self.formLayoutWidget)
        self.lineEdit_currentKI.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_currentKI.setReadOnly(True)
        self.lineEdit_currentKI.setObjectName("lineEdit_currentKI")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.lineEdit_currentKI)
        self.label_8 = QtWidgets.QLabel(self.formLayoutWidget)
        self.label_8.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_8.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_8.setObjectName("label_8")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_8)
        self.lineEdit_speedKP = QtWidgets.QLineEdit(self.formLayoutWidget)
        self.lineEdit_speedKP.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_speedKP.setReadOnly(True)
        self.lineEdit_speedKP.setObjectName("lineEdit_speedKP")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.lineEdit_speedKP)
        self.label_9 = QtWidgets.QLabel(self.formLayoutWidget)
        self.label_9.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_9.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_9.setObjectName("label_9")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.label_9)
        self.lineEdit_speedKI = QtWidgets.QLineEdit(self.formLayoutWidget)
        self.lineEdit_speedKI.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_speedKI.setReadOnly(True)
        self.lineEdit_speedKI.setObjectName("lineEdit_speedKI")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.lineEdit_speedKI)
        self.label_16 = QtWidgets.QLabel(self.formLayoutWidget)
        font = QtGui.QFont()
        font.setItalic(False)
        self.label_16.setFont(font)
        self.label_16.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_16.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_16.setTextFormat(QtCore.Qt.AutoText)
        self.label_16.setAlignment(QtCore.Qt.AlignCenter)
        self.label_16.setObjectName("label_16")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_16)
        self.lineEdit_designedVLBW = QtWidgets.QLineEdit(self.formLayoutWidget)
        self.lineEdit_designedVLBW.setFrame(True)
        self.lineEdit_designedVLBW.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.lineEdit_designedVLBW.setReadOnly(True)
        self.lineEdit_designedVLBW.setObjectName("lineEdit_designedVLBW")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.lineEdit_designedVLBW)
        self.groupBox_5 = QtWidgets.QGroupBox(self.tab_5)
        self.groupBox_5.setGeometry(QtCore.QRect(20, 20, 351, 121))
        self.groupBox_5.setObjectName("groupBox_5")
        self.verticalLayoutWidget_9 = QtWidgets.QWidget(self.groupBox_5)
        self.verticalLayoutWidget_9.setGeometry(QtCore.QRect(10, 20, 321, 91))
        self.verticalLayoutWidget_9.setObjectName("verticalLayoutWidget_9")
        self.verticalLayout_17 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_9)
        self.verticalLayout_17.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_17.setObjectName("verticalLayout_17")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_math_delta = QtWidgets.QLabel(self.verticalLayoutWidget_9)
        font = QtGui.QFont()
        font.setItalic(False)
        self.label_math_delta.setFont(font)
        self.label_math_delta.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_math_delta.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_math_delta.setTextFormat(QtCore.Qt.AutoText)
        self.label_math_delta.setAlignment(QtCore.Qt.AlignCenter)
        self.label_math_delta.setObjectName("label_math_delta")
        self.horizontalLayout_9.addWidget(self.label_math_delta)
        self.lineEdit_dampingFactor_delta = QtWidgets.QLineEdit(self.verticalLayoutWidget_9)
        self.lineEdit_dampingFactor_delta.setFrame(True)
        self.lineEdit_dampingFactor_delta.setObjectName("lineEdit_dampingFactor_delta")
        self.horizontalLayout_9.addWidget(self.lineEdit_dampingFactor_delta)
        self.verticalLayout_17.addLayout(self.horizontalLayout_9)
        self.horizontalLayout_21 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_21.setObjectName("horizontalLayout_21")
        self.label_desiredVLBW = QtWidgets.QLabel(self.verticalLayoutWidget_9)
        self.label_desiredVLBW.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_desiredVLBW.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_desiredVLBW.setObjectName("label_desiredVLBW")
        self.horizontalLayout_21.addWidget(self.label_desiredVLBW)
        self.lineEdit_desiredVLBW = QtWidgets.QLineEdit(self.verticalLayoutWidget_9)
        self.lineEdit_desiredVLBW.setObjectName("lineEdit_desiredVLBW")
        self.horizontalLayout_21.addWidget(self.lineEdit_desiredVLBW)
        self.verticalLayout_17.addLayout(self.horizontalLayout_21)
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_16.addItem(spacerItem2)
        self.pushButton_pidTuner = QtWidgets.QPushButton(self.verticalLayoutWidget_9)
        self.pushButton_pidTuner.setObjectName("pushButton_pidTuner")
        self.horizontalLayout_16.addWidget(self.pushButton_pidTuner)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_16.addItem(spacerItem3)
        self.verticalLayout_17.addLayout(self.horizontalLayout_16)
        self.tabWidget.addTab(self.tab_5, "")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.verticalLayoutWidget_4 = QtWidgets.QWidget(self.tab_4)
        self.verticalLayoutWidget_4.setGeometry(QtCore.QRect(10, 10, 361, 291))
        self.verticalLayoutWidget_4.setObjectName("verticalLayoutWidget_4")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_4)
        self.verticalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.label_4 = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_4.sizePolicy().hasHeightForWidth())
        self.label_4.setSizePolicy(sizePolicy)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_11.addWidget(self.label_4)
        self.lineEdit_RO_MachineName = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_RO_MachineName.setReadOnly(True)
        self.lineEdit_RO_MachineName.setObjectName("lineEdit_RO_MachineName")
        self.horizontalLayout_11.addWidget(self.lineEdit_RO_MachineName)
        self.verticalLayout_7.addLayout(self.horizontalLayout_11)
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout()
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.label_EndTime = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        self.label_EndTime.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_EndTime.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_EndTime.setObjectName("label_EndTime")
        self.verticalLayout_8.addWidget(self.label_EndTime)
        self.label_CLTS = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        self.label_CLTS.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_CLTS.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_CLTS.setObjectName("label_CLTS")
        self.verticalLayout_8.addWidget(self.label_CLTS)
        self.label_VLTS = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        self.label_VLTS.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_VLTS.setObjectName("label_VLTS")
        self.verticalLayout_8.addWidget(self.label_VLTS)
        self.label_npd_12 = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        self.label_npd_12.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_12.setObjectName("label_npd_12")
        self.verticalLayout_8.addWidget(self.label_npd_12)
        self.label_npd_13 = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        self.label_npd_13.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_13.setObjectName("label_npd_13")
        self.verticalLayout_8.addWidget(self.label_npd_13)
        self.label_npd_15 = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        self.label_npd_15.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_15.setObjectName("label_npd_15")
        self.verticalLayout_8.addWidget(self.label_npd_15)
        self.label_npd_14 = QtWidgets.QLabel(self.verticalLayoutWidget_4)
        self.label_npd_14.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_14.setObjectName("label_npd_14")
        self.verticalLayout_8.addWidget(self.label_npd_14)
        self.horizontalLayout_12.addLayout(self.verticalLayout_8)
        self.verticalLayout_9 = QtWidgets.QVBoxLayout()
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.lineEdit_EndTime = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_EndTime.setObjectName("lineEdit_EndTime")
        self.verticalLayout_9.addWidget(self.lineEdit_EndTime)
        self.lineEdit_CLTS = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_CLTS.setObjectName("lineEdit_CLTS")
        self.verticalLayout_9.addWidget(self.lineEdit_CLTS)
        self.lineEdit_VLTS = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_VLTS.setObjectName("lineEdit_VLTS")
        self.verticalLayout_9.addWidget(self.lineEdit_VLTS)
        self.lineEdit_LoadTorque = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_LoadTorque.setObjectName("lineEdit_LoadTorque")
        self.verticalLayout_9.addWidget(self.lineEdit_LoadTorque)
        self.lineEdit_LoadInertiaPercentage = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_LoadInertiaPercentage.setObjectName("lineEdit_LoadInertiaPercentage")
        self.verticalLayout_9.addWidget(self.lineEdit_LoadInertiaPercentage)
        self.lineEdit_ViscousCoefficient = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_ViscousCoefficient.setObjectName("lineEdit_ViscousCoefficient")
        self.verticalLayout_9.addWidget(self.lineEdit_ViscousCoefficient)
        self.lineEdit_OutputDataFileName = QtWidgets.QLineEdit(self.verticalLayoutWidget_4)
        self.lineEdit_OutputDataFileName.setObjectName("lineEdit_OutputDataFileName")
        self.verticalLayout_9.addWidget(self.lineEdit_OutputDataFileName)
        self.horizontalLayout_12.addLayout(self.verticalLayout_9)
        self.verticalLayout_7.addLayout(self.horizontalLayout_12)
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem4)
        self.pushButton_runCBasedSimulation = QtWidgets.QPushButton(self.verticalLayoutWidget_4)
        self.pushButton_runCBasedSimulation.setObjectName("pushButton_runCBasedSimulation")
        self.horizontalLayout_14.addWidget(self.pushButton_runCBasedSimulation)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem5)
        self.verticalLayout_7.addLayout(self.horizontalLayout_14)
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem6)
        self.pushButton_ACMPlotHere = QtWidgets.QPushButton(self.verticalLayoutWidget_4)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.pushButton_ACMPlotHere.setFont(font)
        self.pushButton_ACMPlotHere.setObjectName("pushButton_ACMPlotHere")
        self.horizontalLayout_17.addWidget(self.pushButton_ACMPlotHere)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem7)
        self.pushButton_ACMPlotSeparate = QtWidgets.QPushButton(self.verticalLayoutWidget_4)
        self.pushButton_ACMPlotSeparate.setObjectName("pushButton_ACMPlotSeparate")
        self.horizontalLayout_17.addWidget(self.pushButton_ACMPlotSeparate)
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem8)
        self.verticalLayout_7.addLayout(self.horizontalLayout_17)
        self.horizontalLayoutWidget_2 = QtWidgets.QWidget(self.tab_4)
        self.horizontalLayoutWidget_2.setGeometry(QtCore.QRect(390, 20, 381, 22))
        self.horizontalLayoutWidget_2.setObjectName("horizontalLayoutWidget_2")
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget_2)
        self.horizontalLayout_15.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.label__path2boptPython_2 = QtWidgets.QLabel(self.horizontalLayoutWidget_2)
        self.label__path2boptPython_2.setFrameShape(QtWidgets.QFrame.Panel)
        self.label__path2boptPython_2.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label__path2boptPython_2.setObjectName("label__path2boptPython_2")
        self.horizontalLayout_15.addWidget(self.label__path2boptPython_2)
        self.lineEdit_path2acmsimc = QtWidgets.QLineEdit(self.horizontalLayoutWidget_2)
        self.lineEdit_path2acmsimc.setObjectName("lineEdit_path2acmsimc")
        self.horizontalLayout_15.addWidget(self.lineEdit_path2acmsimc)
        self.verticalLayoutWidget_5 = QtWidgets.QWidget(self.tab_4)
        self.verticalLayoutWidget_5.setGeometry(QtCore.QRect(10, 310, 321, 481))
        self.verticalLayoutWidget_5.setObjectName("verticalLayoutWidget_5")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_5)
        self.verticalLayout_10.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.label__path2boptPython_3 = QtWidgets.QLabel(self.verticalLayoutWidget_5)
        self.label__path2boptPython_3.setFrameShape(QtWidgets.QFrame.Panel)
        self.label__path2boptPython_3.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label__path2boptPython_3.setObjectName("label__path2boptPython_3")
        self.horizontalLayout_19.addWidget(self.label__path2boptPython_3)
        self.lineEdit_path2ACMPlotLabels = QtWidgets.QLineEdit(self.verticalLayoutWidget_5)
        self.lineEdit_path2ACMPlotLabels.setReadOnly(True)
        self.lineEdit_path2ACMPlotLabels.setObjectName("lineEdit_path2ACMPlotLabels")
        self.horizontalLayout_19.addWidget(self.lineEdit_path2ACMPlotLabels)
        self.verticalLayout_10.addLayout(self.horizontalLayout_19)
        self.label_ACMLabels = QtWidgets.QLabel(self.verticalLayoutWidget_5)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_ACMLabels.setFont(font)
        self.label_ACMLabels.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.label_ACMLabels.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_ACMLabels.setAlignment(QtCore.Qt.AlignCenter)
        self.label_ACMLabels.setObjectName("label_ACMLabels")
        self.verticalLayout_10.addWidget(self.label_ACMLabels)
        self.plainTextEdit_ACMPlotLabels = QCodeEditor(self.verticalLayoutWidget_5)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.plainTextEdit_ACMPlotLabels.setFont(font)
        self.plainTextEdit_ACMPlotLabels.setLineWrapMode(QtWidgets.QPlainTextEdit.NoWrap)
        self.plainTextEdit_ACMPlotLabels.setObjectName("plainTextEdit_ACMPlotLabels")
        self.verticalLayout_10.addWidget(self.plainTextEdit_ACMPlotLabels)
        self.verticalLayoutWidget_6 = QtWidgets.QWidget(self.tab_4)
        self.verticalLayoutWidget_6.setGeometry(QtCore.QRect(340, 310, 451, 481))
        self.verticalLayoutWidget_6.setObjectName("verticalLayoutWidget_6")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_6)
        self.verticalLayout_13.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        self.label__path2boptPython_4 = QtWidgets.QLabel(self.verticalLayoutWidget_6)
        self.label__path2boptPython_4.setFrameShape(QtWidgets.QFrame.Panel)
        self.label__path2boptPython_4.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label__path2boptPython_4.setObjectName("label__path2boptPython_4")
        self.horizontalLayout_20.addWidget(self.label__path2boptPython_4)
        self.lineEdit_path2ACMPlotSignals = QtWidgets.QLineEdit(self.verticalLayoutWidget_6)
        self.lineEdit_path2ACMPlotSignals.setReadOnly(True)
        self.lineEdit_path2ACMPlotSignals.setObjectName("lineEdit_path2ACMPlotSignals")
        self.horizontalLayout_20.addWidget(self.lineEdit_path2ACMPlotSignals)
        self.verticalLayout_13.addLayout(self.horizontalLayout_20)
        self.label_ACMLabels_2 = QtWidgets.QLabel(self.verticalLayoutWidget_6)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_ACMLabels_2.setFont(font)
        self.label_ACMLabels_2.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.label_ACMLabels_2.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_ACMLabels_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_ACMLabels_2.setObjectName("label_ACMLabels_2")
        self.verticalLayout_13.addWidget(self.label_ACMLabels_2)
        self.plainTextEdit_ACMPlotDetails = QCodeEditor(self.verticalLayoutWidget_6)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.plainTextEdit_ACMPlotDetails.setFont(font)
        self.plainTextEdit_ACMPlotDetails.setLineWrapMode(QtWidgets.QPlainTextEdit.NoWrap)
        self.plainTextEdit_ACMPlotDetails.setObjectName("plainTextEdit_ACMPlotDetails")
        self.verticalLayout_13.addWidget(self.plainTextEdit_ACMPlotDetails)
        self.verticalLayoutWidget_7 = QtWidgets.QWidget(self.tab_4)
        self.verticalLayoutWidget_7.setGeometry(QtCore.QRect(450, 800, 341, 51))
        self.verticalLayoutWidget_7.setObjectName("verticalLayoutWidget_7")
        self.verticalLayout_CBSMplToolBar = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_7)
        self.verticalLayout_CBSMplToolBar.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_CBSMplToolBar.setObjectName("verticalLayout_CBSMplToolBar")
        self.groupBox = QtWidgets.QGroupBox(self.tab_4)
        self.groupBox.setGeometry(QtCore.QRect(390, 50, 401, 221))
        self.groupBox.setFlat(False)
        self.groupBox.setCheckable(False)
        self.groupBox.setObjectName("groupBox")
        self.gridLayoutWidget = QtWidgets.QWidget(self.groupBox)
        self.gridLayoutWidget.setGeometry(QtCore.QRect(0, 20, 391, 141))
        self.gridLayoutWidget.setObjectName("gridLayoutWidget")
        self.gridLayout = QtWidgets.QGridLayout(self.gridLayoutWidget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setHorizontalSpacing(0)
        self.gridLayout.setVerticalSpacing(10)
        self.gridLayout.setObjectName("gridLayout")
        self.radioButton_Excitation_Velocity = QtWidgets.QRadioButton(self.gridLayoutWidget)
        self.radioButton_Excitation_Velocity.setObjectName("radioButton_Excitation_Velocity")
        self.gridLayout.addWidget(self.radioButton_Excitation_Velocity, 0, 1, 1, 1)
        self.radioButton_Excitation_SweepFrequency = QtWidgets.QRadioButton(self.gridLayoutWidget)
        self.radioButton_Excitation_SweepFrequency.setChecked(True)
        self.radioButton_Excitation_SweepFrequency.setObjectName("radioButton_Excitation_SweepFrequency")
        self.gridLayout.addWidget(self.radioButton_Excitation_SweepFrequency, 0, 2, 1, 1)
        self.radioButton_Excitation_Position = QtWidgets.QRadioButton(self.gridLayoutWidget)
        self.radioButton_Excitation_Position.setObjectName("radioButton_Excitation_Position")
        self.gridLayout.addWidget(self.radioButton_Excitation_Position, 0, 0, 1, 1)
        self.groupBox_sweepFrequency = QtWidgets.QGroupBox(self.gridLayoutWidget)
        self.groupBox_sweepFrequency.setEnabled(True)
        self.groupBox_sweepFrequency.setObjectName("groupBox_sweepFrequency")
        self.verticalLayoutWidget_10 = QtWidgets.QWidget(self.groupBox_sweepFrequency)
        self.verticalLayoutWidget_10.setGeometry(QtCore.QRect(10, 20, 113, 87))
        self.verticalLayoutWidget_10.setObjectName("verticalLayoutWidget_10")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_10)
        self.verticalLayout_14.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.radioButton_openLoop = QtWidgets.QRadioButton(self.verticalLayoutWidget_10)
        self.radioButton_openLoop.setAutoExclusive(False)
        self.radioButton_openLoop.setObjectName("radioButton_openLoop")
        self.verticalLayout_14.addWidget(self.radioButton_openLoop)
        self.radioButton_currentLoopOnly = QtWidgets.QRadioButton(self.verticalLayoutWidget_10)
        self.radioButton_currentLoopOnly.setAutoExclusive(False)
        self.radioButton_currentLoopOnly.setObjectName("radioButton_currentLoopOnly")
        self.verticalLayout_14.addWidget(self.radioButton_currentLoopOnly)
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setSpacing(0)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.label_maxFreq2Sweep = QtWidgets.QLabel(self.verticalLayoutWidget_10)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_maxFreq2Sweep.sizePolicy().hasHeightForWidth())
        self.label_maxFreq2Sweep.setSizePolicy(sizePolicy)
        self.label_maxFreq2Sweep.setObjectName("label_maxFreq2Sweep")
        self.horizontalLayout_13.addWidget(self.label_maxFreq2Sweep)
        self.lineEdit_maxFreq2Sweep = QtWidgets.QLineEdit(self.verticalLayoutWidget_10)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit_maxFreq2Sweep.sizePolicy().hasHeightForWidth())
        self.lineEdit_maxFreq2Sweep.setSizePolicy(sizePolicy)
        self.lineEdit_maxFreq2Sweep.setObjectName("lineEdit_maxFreq2Sweep")
        self.horizontalLayout_13.addWidget(self.lineEdit_maxFreq2Sweep)
        self.verticalLayout_14.addLayout(self.horizontalLayout_13)
        self.gridLayout.addWidget(self.groupBox_sweepFrequency, 1, 2, 1, 1)
        self.tabWidget.addTab(self.tab_4, "")
        self.tab_6 = QtWidgets.QWidget()
        self.tab_6.setObjectName("tab_6")
        self.layoutWidget_2 = QtWidgets.QWidget(self.tab_6)
        self.layoutWidget_2.setGeometry(QtCore.QRect(240, 10, 311, 25))
        self.layoutWidget_2.setObjectName("layoutWidget_2")
        self.horizontalLayout_22 = QtWidgets.QHBoxLayout(self.layoutWidget_2)
        self.horizontalLayout_22.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_22.setObjectName("horizontalLayout_22")
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_22.addItem(spacerItem9)
        self.pushButton_bodePlot = QtWidgets.QPushButton(self.layoutWidget_2)
        self.pushButton_bodePlot.setObjectName("pushButton_bodePlot")
        self.horizontalLayout_22.addWidget(self.pushButton_bodePlot)
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_22.addItem(spacerItem10)
        self.MplWidget_bodePlot = MplWidget(self.tab_6)
        self.MplWidget_bodePlot.setGeometry(QtCore.QRect(20, 40, 789, 837))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MplWidget_bodePlot.sizePolicy().hasHeightForWidth())
        self.MplWidget_bodePlot.setSizePolicy(sizePolicy)
        self.MplWidget_bodePlot.setObjectName("MplWidget_bodePlot")
        self.tabWidget.addTab(self.tab_6, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.verticalLayoutWidget_2 = QtWidgets.QWidget(self.tab_2)
        self.verticalLayoutWidget_2.setGeometry(QtCore.QRect(0, 0, 791, 881))
        self.verticalLayoutWidget_2.setObjectName("verticalLayoutWidget_2")
        self.verticalLayout_inTab2 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_2)
        self.verticalLayout_inTab2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_inTab2.setObjectName("verticalLayout_inTab2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem11 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem11)
        self.pushButton_getSignal = QtWidgets.QPushButton(self.verticalLayoutWidget_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.pushButton_getSignal.setFont(font)
        self.pushButton_getSignal.setObjectName("pushButton_getSignal")
        self.horizontalLayout_2.addWidget(self.pushButton_getSignal)
        spacerItem12 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem12)
        self.verticalLayout_inTab2.addLayout(self.horizontalLayout_2)
        self.MplWidget = MplWidget(self.verticalLayoutWidget_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MplWidget.sizePolicy().hasHeightForWidth())
        self.MplWidget.setSizePolicy(sizePolicy)
        self.MplWidget.setObjectName("MplWidget")
        self.verticalLayout_inTab2.addWidget(self.MplWidget)
        self.tabWidget.addTab(self.tab_2, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.verticalLayoutWidget_3 = QtWidgets.QWidget(self.tab_3)
        self.verticalLayoutWidget_3.setGeometry(QtCore.QRect(30, 420, 361, 248))
        self.verticalLayoutWidget_3.setObjectName("verticalLayoutWidget_3")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_3)
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        self.label.setObjectName("label")
        self.horizontalLayout_7.addWidget(self.label)
        self.comboBox_FEAConfig = QtWidgets.QComboBox(self.verticalLayoutWidget_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_FEAConfig.sizePolicy().hasHeightForWidth())
        self.comboBox_FEAConfig.setSizePolicy(sizePolicy)
        self.comboBox_FEAConfig.setBaseSize(QtCore.QSize(0, 0))
        self.comboBox_FEAConfig.setObjectName("comboBox_FEAConfig")
        self.horizontalLayout_7.addWidget(self.comboBox_FEAConfig)
        self.verticalLayout_4.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.label_3 = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_3.sizePolicy().hasHeightForWidth())
        self.label_3.setSizePolicy(sizePolicy)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_8.addWidget(self.label_3)
        self.comboBox_MachineSpec = QtWidgets.QComboBox(self.verticalLayoutWidget_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_MachineSpec.sizePolicy().hasHeightForWidth())
        self.comboBox_MachineSpec.setSizePolicy(sizePolicy)
        self.comboBox_MachineSpec.setObjectName("comboBox_MachineSpec")
        self.horizontalLayout_8.addWidget(self.comboBox_MachineSpec)
        self.verticalLayout_4.addLayout(self.horizontalLayout_8)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.label_npd_5 = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        self.label_npd_5.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_5.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label_npd_5.setObjectName("label_npd_5")
        self.verticalLayout_5.addWidget(self.label_npd_5)
        self.label_npd_6 = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        self.label_npd_6.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_6.setObjectName("label_npd_6")
        self.verticalLayout_5.addWidget(self.label_npd_6)
        self.label_npd_7 = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        self.label_npd_7.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_7.setObjectName("label_npd_7")
        self.verticalLayout_5.addWidget(self.label_npd_7)
        self.label_npd_8 = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        self.label_npd_8.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_8.setObjectName("label_npd_8")
        self.verticalLayout_5.addWidget(self.label_npd_8)
        self.label_npd_9 = QtWidgets.QLabel(self.verticalLayoutWidget_3)
        self.label_npd_9.setFrameShape(QtWidgets.QFrame.Panel)
        self.label_npd_9.setObjectName("label_npd_9")
        self.verticalLayout_5.addWidget(self.label_npd_9)
        self.horizontalLayout_3.addLayout(self.verticalLayout_5)
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.lineEdit_npp_2 = QtWidgets.QLineEdit(self.verticalLayoutWidget_3)
        self.lineEdit_npp_2.setObjectName("lineEdit_npp_2")
        self.verticalLayout_6.addWidget(self.lineEdit_npp_2)
        self.lineEdit_RatedCurrent_2 = QtWidgets.QLineEdit(self.verticalLayoutWidget_3)
        self.lineEdit_RatedCurrent_2.setObjectName("lineEdit_RatedCurrent_2")
        self.verticalLayout_6.addWidget(self.lineEdit_RatedCurrent_2)
        self.lineEdit_RatedPower_2 = QtWidgets.QLineEdit(self.verticalLayoutWidget_3)
        self.lineEdit_RatedPower_2.setObjectName("lineEdit_RatedPower_2")
        self.verticalLayout_6.addWidget(self.lineEdit_RatedPower_2)
        self.lineEdit_RatedSpeed_2 = QtWidgets.QLineEdit(self.verticalLayoutWidget_3)
        self.lineEdit_RatedSpeed_2.setObjectName("lineEdit_RatedSpeed_2")
        self.verticalLayout_6.addWidget(self.lineEdit_RatedSpeed_2)
        self.lineEdit_RatedSpeed_3 = QtWidgets.QLineEdit(self.verticalLayoutWidget_3)
        self.lineEdit_RatedSpeed_3.setObjectName("lineEdit_RatedSpeed_3")
        self.verticalLayout_6.addWidget(self.lineEdit_RatedSpeed_3)
        self.horizontalLayout_3.addLayout(self.verticalLayout_6)
        self.verticalLayout_4.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        spacerItem13 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem13)
        self.pushButton_updateModel_2 = QtWidgets.QPushButton(self.verticalLayoutWidget_3)
        self.pushButton_updateModel_2.setObjectName("pushButton_updateModel_2")
        self.horizontalLayout_5.addWidget(self.pushButton_updateModel_2)
        spacerItem14 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem14)
        self.verticalLayout_4.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        spacerItem15 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_10.addItem(spacerItem15)
        self.pushButton_updateModel_4 = QtWidgets.QPushButton(self.verticalLayoutWidget_3)
        self.pushButton_updateModel_4.setObjectName("pushButton_updateModel_4")
        self.horizontalLayout_10.addWidget(self.pushButton_updateModel_4)
        spacerItem16 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_10.addItem(spacerItem16)
        self.verticalLayout_4.addLayout(self.horizontalLayout_10)
        self.horizontalLayoutWidget = QtWidgets.QWidget(self.tab_3)
        self.horizontalLayoutWidget.setGeometry(QtCore.QRect(480, 30, 227, 22))
        self.horizontalLayoutWidget.setObjectName("horizontalLayoutWidget")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget)
        self.horizontalLayout_6.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.label__path2boptPython = QtWidgets.QLabel(self.horizontalLayoutWidget)
        self.label__path2boptPython.setFrameShape(QtWidgets.QFrame.Panel)
        self.label__path2boptPython.setFrameShadow(QtWidgets.QFrame.Plain)
        self.label__path2boptPython.setObjectName("label__path2boptPython")
        self.horizontalLayout_6.addWidget(self.label__path2boptPython)
        self.lineEdit_path2boptPython = QtWidgets.QLineEdit(self.horizontalLayoutWidget)
        self.lineEdit_path2boptPython.setObjectName("lineEdit_path2boptPython")
        self.horizontalLayout_6.addWidget(self.lineEdit_path2boptPython)
        self.tabWidget.addTab(self.tab_3, "")
        self.verticalLayout_12.addWidget(self.tabWidget)
        self.scrollArea_CBS_Left.setWidget(self.scrollAreaWidgetContents_3)
        self.horizontalLayout_18.addWidget(self.scrollArea_CBS_Left)
        self.scrollArea_2 = QtWidgets.QScrollArea(self.centralwidget)
        self.scrollArea_2.setMinimumSize(QtCore.QSize(0, 800))
        self.scrollArea_2.setWidgetResizable(True)
        self.scrollArea_2.setObjectName("scrollArea_2")
        self.scrollAreaWidgetContents_2 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_2.setGeometry(QtCore.QRect(0, 0, 842, 1154))
        self.scrollAreaWidgetContents_2.setObjectName("scrollAreaWidgetContents_2")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_2)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.MplWidget_ACMPlot = MplWidget(self.scrollAreaWidgetContents_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.MplWidget_ACMPlot.sizePolicy().hasHeightForWidth())
        self.MplWidget_ACMPlot.setSizePolicy(sizePolicy)
        self.MplWidget_ACMPlot.setMinimumSize(QtCore.QSize(800, 800))
        self.MplWidget_ACMPlot.setStyleSheet("background-color: rgb(170, 0, 127)")
        self.MplWidget_ACMPlot.setObjectName("MplWidget_ACMPlot")
        self.verticalLayout_11.addWidget(self.MplWidget_ACMPlot)
        self.scrollArea_2.setWidget(self.scrollAreaWidgetContents_2)
        self.horizontalLayout_18.addWidget(self.scrollArea_2)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1712, 21))
        self.menubar.setObjectName("menubar")
        self.menuLoad = QtWidgets.QMenu(self.menubar)
        self.menuLoad.setObjectName("menuLoad")
        self.menuTheme = QtWidgets.QMenu(self.menubar)
        self.menuTheme.setObjectName("menuTheme")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionLocate = QtWidgets.QAction(MainWindow)
        self.actionLocate.setObjectName("actionLocate")
        self.actionDark = QtWidgets.QAction(MainWindow)
        self.actionDark.setObjectName("actionDark")
        self.actionLight = QtWidgets.QAction(MainWindow)
        self.actionLight.setObjectName("actionLight")
        self.menuLoad.addAction(self.actionLocate)
        self.menuTheme.addAction(self.actionDark)
        self.menuTheme.addAction(self.actionLight)
        self.menubar.addAction(self.menuLoad.menuAction())
        self.menubar.addAction(self.menuTheme.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.comboBox_MachineType.setItemText(0, _translate("MainWindow", "Synchronous Machine"))
        self.comboBox_MachineType.setItemText(1, _translate("MainWindow", "Induction Machine"))
        self.label_npd.setText(_translate("MainWindow", "Number of Pole Pairs"))
        self.label_npd_2.setText(_translate("MainWindow", "Rated Current [Arms]"))
        self.label_npd_3.setText(_translate("MainWindow", "Rated Power [W]"))
        self.label_npd_4.setText(_translate("MainWindow", "Rated Speed [rpm]"))
        self.lineEdit_npp.setText(_translate("MainWindow", "0"))
        self.lineEdit_RatedCurrent.setText(_translate("MainWindow", "0"))
        self.lineEdit_RatedPower.setText(_translate("MainWindow", "0"))
        self.lineEdit_RatedSpeed.setText(_translate("MainWindow", "0"))
        self.pushButton_updateModel.setText(_translate("MainWindow", "Update Model"))
        self.label_pushedVariables.setText(_translate("MainWindow", "None"))
        self.label_pushedVariables0.setText(_translate("MainWindow", "Variables Pushed qtConsole: "))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("MainWindow", "Name Plate Data"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Theory"))
        self.groupBox_3.setTitle(_translate("MainWindow", "User Tuning"))
        self.label_12.setText(_translate("MainWindow", "上位机Current KP"))
        self.lineEdit_PC_currentKP.setText(_translate("MainWindow", "0"))
        self.label_13.setText(_translate("MainWindow", "上位机Current KI"))
        self.lineEdit_PC_currentKI.setText(_translate("MainWindow", "0"))
        self.label_14.setText(_translate("MainWindow", "上位机Speed KP"))
        self.lineEdit_PC_speedKP.setText(_translate("MainWindow", "0"))
        self.label_15.setText(_translate("MainWindow", "上位机Speed KI"))
        self.lineEdit_PC_speedKI.setText(_translate("MainWindow", "0"))
        self.groupBox_4.setTitle(_translate("MainWindow", "Output"))
        self.label_7.setText(_translate("MainWindow", "Current Loop Bandwidth [Hz]"))
        self.lineEdit_CLBW.setText(_translate("MainWindow", "0"))
        self.label_10.setText(_translate("MainWindow", "Current KP"))
        self.lineEdit_currentKP.setText(_translate("MainWindow", "0"))
        self.label_11.setText(_translate("MainWindow", "Current KI"))
        self.lineEdit_currentKI.setText(_translate("MainWindow", "0"))
        self.label_8.setText(_translate("MainWindow", "Speed KP"))
        self.lineEdit_speedKP.setText(_translate("MainWindow", "0"))
        self.label_9.setText(_translate("MainWindow", "Speed KI"))
        self.lineEdit_speedKI.setText(_translate("MainWindow", "0"))
        self.label_16.setText(_translate("MainWindow", "Velocity Loop Bandwidth [Hz]"))
        self.lineEdit_designedVLBW.setText(_translate("MainWindow", "0"))
        self.groupBox_5.setTitle(_translate("MainWindow", "Input"))
        self.label_math_delta.setText(_translate("MainWindow", "Dampling Factor δ [1]"))
        self.lineEdit_dampingFactor_delta.setText(_translate("MainWindow", "6.5"))
        self.label_desiredVLBW.setText(_translate("MainWindow", "Desired Velocity Loop Bandwidth [Hz]"))
        self.lineEdit_desiredVLBW.setText(_translate("MainWindow", "100"))
        self.pushButton_pidTuner.setText(_translate("MainWindow", "Get Output"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_5), _translate("MainWindow", "Controller Tuning"))
        self.label_4.setText(_translate("MainWindow", "Selected Machine Name"))
        self.label_EndTime.setText(_translate("MainWindow", "End Time [s]"))
        self.label_CLTS.setText(_translate("MainWindow", "Current Loop TS [1/Hz]"))
        self.label_VLTS.setText(_translate("MainWindow", "Velocity Loop TS [1/Hz]]"))
        self.label_npd_12.setText(_translate("MainWindow", "Load Torque [Nm]"))
        self.label_npd_13.setText(_translate("MainWindow", "Load Inertia Percentage [%]"))
        self.label_npd_15.setText(_translate("MainWindow", "Viscous Coefficient [Nm/elec.rad*s]"))
        self.label_npd_14.setText(_translate("MainWindow", "Output File Name Prefix@acmsimc"))
        self.lineEdit_EndTime.setText(_translate("MainWindow", "10"))
        self.lineEdit_CLTS.setText(_translate("MainWindow", "1/20e3"))
        self.lineEdit_VLTS.setText(_translate("MainWindow", "4/20e3"))
        self.lineEdit_LoadTorque.setText(_translate("MainWindow", "0.0"))
        self.lineEdit_LoadInertiaPercentage.setText(_translate("MainWindow", "16"))
        self.lineEdit_ViscousCoefficient.setText(_translate("MainWindow", "0.7e-4"))
        self.lineEdit_OutputDataFileName.setText(_translate("MainWindow", "PMSM_SweepFreq"))
        self.pushButton_runCBasedSimulation.setText(_translate("MainWindow", "Run Simulation"))
        self.pushButton_ACMPlotHere.setText(_translate("MainWindow", "Plot Here"))
        self.pushButton_ACMPlotSeparate.setText(_translate("MainWindow", "Plot in Separate Window"))
        self.label__path2boptPython_2.setText(_translate("MainWindow", "Path to acmsimc"))
        self.lineEdit_path2acmsimc.setText(_translate("MainWindow", "D:\\DrH\\Codes\\emachineryTestPYPI\\emachinery\\acmsimcv5"))
        self.label__path2boptPython_3.setText(_translate("MainWindow", "Path to plot labels file"))
        self.lineEdit_path2ACMPlotLabels.setText(_translate("MainWindow", "./plot_setting_files/labels.txt"))
        self.label_ACMLabels.setText(_translate("MainWindow", "Labels"))
        self.plainTextEdit_ACMPlotLabels.setPlainText(_translate("MainWindow", "None"))
        self.label__path2boptPython_4.setText(_translate("MainWindow", "Path to plot signals file"))
        self.lineEdit_path2ACMPlotSignals.setText(_translate("MainWindow", "./plot_setting_files/signals.txt"))
        self.label_ACMLabels_2.setText(_translate("MainWindow", "Signals"))
        self.plainTextEdit_ACMPlotDetails.setPlainText(_translate("MainWindow", "None"))
        self.groupBox.setTitle(_translate("MainWindow", "Select Excitation:"))
        self.radioButton_Excitation_Velocity.setText(_translate("MainWindow", "Velocity"))
        self.radioButton_Excitation_SweepFrequency.setText(_translate("MainWindow", "Sweep Frequency"))
        self.radioButton_Excitation_Position.setText(_translate("MainWindow", "Position"))
        self.groupBox_sweepFrequency.setTitle(_translate("MainWindow", "Settings"))
        self.radioButton_openLoop.setText(_translate("MainWindow", "Open loop"))
        self.radioButton_currentLoopOnly.setText(_translate("MainWindow", "Current Loop Only"))
        self.label_maxFreq2Sweep.setText(_translate("MainWindow", "Max Freq."))
        self.lineEdit_maxFreq2Sweep.setText(_translate("MainWindow", "200"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), _translate("MainWindow", "C-based Simulation"))
        self.pushButton_bodePlot.setText(_translate("MainWindow", "Bode Plot by Sweep Freuquency"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_6), _translate("MainWindow", "Bode Plot"))
        self.pushButton_getSignal.setText(_translate("MainWindow", "Generate\n"
"Signals"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("MainWindow", "Plots"))
        self.label.setText(_translate("MainWindow", "FEA Configuration     "))
        self.label_3.setText(_translate("MainWindow", "Machine Specification"))
        self.label_npd_5.setText(_translate("MainWindow", "Number of Poles"))
        self.label_npd_6.setText(_translate("MainWindow", "Rated Current [Arms]"))
        self.label_npd_7.setText(_translate("MainWindow", "Rated Power [W]"))
        self.label_npd_8.setText(_translate("MainWindow", "Rated Speed [rpm]"))
        self.label_npd_9.setText(_translate("MainWindow", "Output Folder Name"))
        self.lineEdit_npp_2.setText(_translate("MainWindow", "0"))
        self.lineEdit_RatedCurrent_2.setText(_translate("MainWindow", "0"))
        self.lineEdit_RatedPower_2.setText(_translate("MainWindow", "50000"))
        self.lineEdit_RatedSpeed_2.setText(_translate("MainWindow", "30000"))
        self.lineEdit_RatedSpeed_3.setText(_translate("MainWindow", "default/"))
        self.pushButton_updateModel_2.setText(_translate("MainWindow", "Run for Fun"))
        self.pushButton_updateModel_4.setText(_translate("MainWindow", "Start Optimization"))
        self.label__path2boptPython.setText(_translate("MainWindow", "Path to bopt-python"))
        self.lineEdit_path2boptPython.setText(_translate("MainWindow", "D:\\DrH\\bopt-python"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), _translate("MainWindow", "FEA-based Optimization (Under Development)"))
        self.menuLoad.setTitle(_translate("MainWindow", "Load"))
        self.menuTheme.setTitle(_translate("MainWindow", "Theme"))
        self.actionLocate.setText(_translate("MainWindow", "Json File"))
        self.actionDark.setText(_translate("MainWindow", "Dark"))
        self.actionLight.setText(_translate("MainWindow", "Light"))
# from consolewidget import ConsoleWidget
# from mplwidget import MplWidget
# from qcodeeditor import QCodeEditor


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())
